@@ -1,12 +1,14 @@
 package Grammar::Marpa;
 
+use strict;
+use warnings;
 use 5.018;
 use utf8;
 use overload ('qr' => 'regexify', fallback => 0);
 
 use Marpa::R2;
 
-our $VERSION = '2.000';
+our $VERSION = '2.001';
 
 sub regexify {
     my ($grammar) = @_;
@@ -61,11 +63,11 @@ __END__
 
 =head1 NAME
 
-Grammar::Marpa - Overload wrapper around Marpa::R2::Scanless
+Grammar::Marpa - Regexp-overloading wrapper around Marpa::R2::Scanless
 
 =head1 VERSION
 
-Version 2.000
+Version 2.001
 
 =head1 SYNOPSIS
 
@@ -178,4 +180,8 @@ The previous version of this module would Carp::confess() if no parse was found.
 
 The current version simply returns implicit undef.
 
+=head LICENSE
+
+Artistic 2.0 - Same terms as Perl itself
+
 =cut
